{- This file is part of funbot.
 -
 - Written in 2015 by fr33domlover <fr33domlover@rel4tion.org>.
 -
 - ♡ Copying is an act of love. Please copy, reuse and share.
 -
 - The author(s) have dedicated all copyright and related and neighboring
 - rights to this software to the public domain worldwide. This software is
 - distributed without any warranty.
 -
 - You should have received a copy of the CC0 Public Domain Dedication along
 - with this software. If not, see
 - <http://creativecommons.org/publicdomain/zero/1.0/>.
 -}

module FunBot.Sources
    ( feedWatcherSource
    , webListenerSource
    , loopbackSource
    )
where

import FunBot.Sources.FeedWatcher (feedWatcherSource)
import FunBot.Sources.WebListener (webListenerSource)
import FunBot.Sources.Loopback (loopbackSource)
